summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/widgets/tqframe.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-07-17 19:19:26 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-07-17 19:19:26 -0500
commit33d3ec06354d07cbb6164eb1c8adbd89c9ecefdd (patch)
tree4939d6567b50d0dd669257422a6868aa1259e62b /tqtinterface/qt4/src/widgets/tqframe.cpp
parentf01eee0362e54f47d0266295c5263790c04b6510 (diff)
downloadexperimental-33d3ec06354d07cbb6164eb1c8adbd89c9ecefdd.tar.gz
experimental-33d3ec06354d07cbb6164eb1c8adbd89c9ecefdd.zip
Revert "Rename tqsize* to size*"
This reverts commit e33879600503bacc0b4ef090f7f79ab80bb6b0da.
Diffstat (limited to 'tqtinterface/qt4/src/widgets/tqframe.cpp')
-rw-r--r--tqtinterface/qt4/src/widgets/tqframe.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tqtinterface/qt4/src/widgets/tqframe.cpp b/tqtinterface/qt4/src/widgets/tqframe.cpp
index 4bce9b1..f49b30c 100644
--- a/tqtinterface/qt4/src/widgets/tqframe.cpp
+++ b/tqtinterface/qt4/src/widgets/tqframe.cpp
@@ -476,18 +476,18 @@ TQRect TQFrame::contentsRect() const
/*!\reimp
*/
-TQSize TQFrame::sizeHint() const
+TQSize TQFrame::tqsizeHint() const
{
// Returns a size hint for the frame - for HLine and VLine
// tqshapes, this is stretchable one way and 3 pixels wide the
// other. For other tqshapes, TQWidget::sizeHint() is used.
switch (fstyle & MShape) {
case HLine:
return TQSize(-1,3);
case VLine:
return TQSize(3,-1);
default:
- return TQWidget::sizeHint();
+ return TQWidget::tqsizeHint();
}
}
@@ -476,18 +476,18 @@ TQRect TQFrame::contentsRect() const
// Returns a size hint for the frame - for HLine and VLine
// tqshapes, this is stretchable one way and 3 pixels wide the
- // other. For other tqshapes, TQWidget::sizeHint() is used.
+ // other. For other tqshapes, TQWidget::tqsizeHint() is used.
switch (fstyle & MShape) {
case HLine: